@@ -4,11 +4,11 @@ use warnings FATAL => 'all';
 package Apache::SWIT::DB::Connection;
 use base 'Class::Data::Inheritable', 'Class::Accessor';
 use DBIx::ContextualFetch;
+use Carp;
 
-__PACKAGE__->mk_classdata('AppName');
 __PACKAGE__->mk_classdata('Instance');
-__PACKAGE__->mk_classdata('DBIArgs', {
-			RaiseError => 1, AutoCommit => 1,
+__PACKAGE__->mk_classdata('DBIArgs', { PrintError => 0
+			, RaiseError => 1, AutoCommit => 1,
 			RootClass => 'DBIx::ContextualFetch', });
 
 __PACKAGE__->mk_accessors(qw(db_handle pid));
@@ -28,11 +28,11 @@ sub instance {
 
 sub connect {
 	my $class = shift;
-	my $db_name = $class->AppName . "_DB_NAME";
-	die "No $db_name given!" unless $ENV{$db_name};
-	my $dbh = DBI->connect("dbi:Pg:dbname=" . $ENV{$db_name}
+	my $dbn = $ENV{APACHE_SWIT_DB_NAME} 
+			or confess "# No \$ENV{APACHE_SWIT_DB_NAME} given!";
+	my $dbh = DBI->connect("dbi:Pg:dbname=$dbn"
 				, undef, undef, $class->DBIArgs)
-		or die "Unable to connect to $ENV{$db_name} db";
+		or die "Unable to connect to $dbn db";
 	return $dbh;
 }
 
